@@ -5,6 +5,8 @@
 #define DUMMYDATE
 #elif defined CF_AlphaLinux
 #define DUMMYDATE
+#elif defined MACOSX
+#define DUMMYDATE
 #endif
 
 #if defined DUMMYDATE
@@ -68,7 +70,6 @@ c         KKMAT = -1
 c         call DT_KKINC(
 c     *   1, 1, ia, iz,  1, ELAB, KKMAT, icon)
       endif
-      
 
       KKMAT = -1
       NEVENT = NEVENT + 1 
@@ -146,8 +147,9 @@ c                  if(loopc .gt. 100) then    ! probably useless.
      *                    ' proj code, subcode, charge=',pj.code,
      *                    pj.subcode, pj.charge, ' E=',pj.fm.p(4),
      *                    ' Target A=', ia, ' Z=', iz
+                     call cpdpmjetinp
                      call cerrorMsg(
-     *              'dpmjet3 loop>100; ptcl generatation failed',0)     
+     *              'dpmjet3 loop>3; ptcl generatation failed',0)     
                   endif
                endif
             enddo
@@ -358,7 +360,8 @@ c                 k0; disregard  short or long but see ptlc or anti
                idp = 24
             else
 c                 k0_bar
-               idp = 25
+cccc               idp = 25
+               idp = 24   ! tentative setting. k0bar will die easily
             endif
          elseif(pj.code .eq. klambda) then
             if(pj.subcode .eq. antip) then
