@@ -105,6 +105,7 @@ c                   electron size in B approx.
 c                   size weighted age
          write(*, *) (ASObsSites(i).age,   i=1, NoOfASSites) 
       endif
+
       end
 
 
@@ -124,12 +125,12 @@ c     *
      * '****** Congratulations: Cosmos is now your friend *******'
 
       if(Trace .gt. 0) then
-         tracefile = TraceDir(1:klena(TraceDir))//'/trace1'
+         tracefile = TraceDir(1:klena(TraceDir))//'/trace?'
          write(*, *)
      * '       particle trace data has been created'//
      *     ' in '//tracefile
          write(*, *)
-     * '       you can see it by gnuplot: For that, in gnuplot do'
+     * ' ?=1,2..you can see it by gnuplot: For that, in gnuplot do'
          write(*, *)
      * '       set para'
          write(*, *)
