@@ -61,6 +61,8 @@ c        reset parameters.
          BorderHeightH = HeightOfInj + 1.0d0    ! from v6.10
       endif
 
+      EventsInTheRun = 0      ! moved from ciniTracking0. 2001.09/30
+
       if(DestEventNo(2) .eq. 0) then
          DestEventNo(2) = DestEventNo(1)
       elseif(DestEventNo(1) .lt. 0) then
@@ -167,7 +169,7 @@ c
          SkipPtclGen = 0
       endif
 
-      EventsInTheRun = 0
+
 
       RefreshIR = InitRN(1) .lt. 0 .and. 
      *        ( Job .ne. 'flesh' .and. Job .ne. 'newflesh')
@@ -179,9 +181,9 @@ c      *****************
 #if defined Solaris
          now(1)= time()
 #else
-         call time(now(1))
+         call time(now)
 #endif
-         now(2) =-InitRN(2)
+c         now(2) =-InitRN(2)  !  2001.09.30; dec fortran changes now(2).
          call rnd1r(now)
 c     ******************
       endif
