@@ -173,7 +173,7 @@ c              whennever an interaction occur,  update labelcounter
 c             if info>0, clear the timer and infor counters.
 c
             if(aTrack.info .gt. 0) then
-               aTrack.info = 0
+ccc               aTrack.info = 0
                aTrack.t = 0.
             endif
             Labelcounter = Labelcounter + 1
@@ -214,47 +214,47 @@ c
 
       reset = .true.
 
-      if(IntInfArray(ProcessNo).process .eq. 'brems' ) then
-c            for brem, electron has the same label as the incident
-         if(aTrack.p.code .eq. kelec ) then
+      if( iTrack.pos.height .gt. 40.d3 ) then
+         if(IntInfArray(ProcessNo).process .eq. 'brems' ) then
+c             for brem, electron has the same label as the incident
             if( aTrack.p.fm.p(4) .lt. iTrack.p.fm.p(4)*0.8) then
                aTrack.label = iTrack.label
                reset = .false.
             endif
-         endif
-      elseif(IntInfArray(ProcessNo).process .eq. 'knock' .or.
-     *         IntInfArray(ProcessNo).process .eq. 'mscat' .or.
+         elseif(IntInfArray(ProcessNo).process .eq. 'knock' .or.
+     *        IntInfArray(ProcessNo).process .eq. 'mscat' .or.
      *         IntInfArray(ProcessNo).process .eq. 'bscat' ) then
 c                for the knock-on, survival particle has the same
 c                label.
-         if(iTrack.p.code .ne. kelec  .or.
-     *        iTrack.p.charge .ne. -1) then
+            if(iTrack.p.code .ne. kelec  .or.
+     *           iTrack.p.charge .ne. -1) then
 c                     knockon by p,mu,pi..e+ (not by e-)
-            if(aTrack.p.code .ne. kelec) then
+               if(aTrack.p.code .ne. kelec) then
 c                       survival one has the same label
-               aTrack.label = iTrack.label
-               reset = .false.
-            endif
-         else
-c                  electron; make the higher one has the same label
-            if(pw(1).fm.p(4) .gt. pw(2).fm.p(4)) then
-               if(i .eq. 1) then
                   aTrack.label = iTrack.label
                   reset = .false.
                endif
             else
-               if(i .eq. 2) then
-                  aTrack.label = iTrack.label
-                  reset = .false.
+c                  electron; make the higher one has the same label
+               if(pw(1).fm.p(4) .gt. pw(2).fm.p(4)) then
+                  if(i .eq. 1) then
+                     aTrack.label = iTrack.label
+                     reset = .false.
+                  endif
+               else
+                  if(i .eq. 2) then
+                     aTrack.label = iTrack.label
+                     reset = .false.
+                  endif
                endif
-            endif
-         endif                     
+            endif                     
+         endif
       endif
       if(reset) then
          Labelcounter = Labelcounter +1
          aTrack.label = Labelcounter
          aTrack.t = 0.          ! timer reset
-         aTrack.info = 0        ! cross counter reset
+cc         aTrack.info = 0        ! cross counter reset
       endif
       end
 #endif
@@ -325,7 +325,7 @@ c               if the particle has crossed the highest level
 c               (info > 0),  timer and info counter is cleared
 c
                if( aTrack.info .gt. 0) then
-                  aTrack.info = 0
+ccc                  aTrack.info = 0
                   aTrack.t = 0.
                endif
                Labelcounter = Labelcounter + 1
